@@ -75,8 +75,8 @@ typedef struct stringlist_s stringlist_t;
 struct ssearch_s 
 {
   char *song;               /* title with pathname componentes stripped */
-  char *fn;                 /* title as sent by server */
-  char *cmp;                /* nickname of remote user */
+  char *rfn;                /* title as sent by server */
+  char *nick;               /* nickname of remote user */
   int conn;                 /* connection speed of remote client */
   unsigned int sz;          /* total size */
   int brate;                /* bitrate (e.g. 128) */
@@ -559,8 +559,11 @@ O_NAP_FUNC(dsavechannels);
 O_NAP_FUNC(dloadchannels);
 O_NAP_FUNC(decho);
 O_NAP_FUNC(dresults);
+O_NAP_FUNC(ddlul);
 O_NAP_FUNC(dexec);
 O_NAP_FUNC(dtimer);
+O_NAP_FUNC(drepeat);
+O_NAP_FUNC(ddtimer);
 O_NAP_FUNC(dif);
 O_NAP_FUNC(ddone);
 O_NAP_FUNC(dwhile);
@@ -592,6 +595,7 @@ char *cspstr(char **, int, int);
 int dupload(upload_t *);
 int ddownload(WINDOW *win, download_t *task);
 int interrupt_download(WINDOW *win, download_t *task);
+int move_to_dir(WINDOW *win, download_t *task, const char *dir, char **lfn);
 void move_to_downloaddir(WINDOW *win, download_t *task);
 void mark_incomplete(WINDOW *win, download_t *task);
 void tagincompletefile(char *fn, itag_t *itag);
@@ -602,6 +606,9 @@ void timed_dup(void *data);
 void timed_ddown(void *data);
 void timed_command(void *data);
 int requestdownload(int s, ssearch_t *sitem);
+int retrydownload(int s, download_t *dl);
+int forcedownload(int s, download_t *dl);
+int unused_filename(const char *path, const char *fn, const char *suffix, char **lfn, char **newfn);
 int opendownloadfile(char *fn, FILE **f, char **lfn);
 void qevent(void);
 int parse_range(char *range);
@@ -614,6 +621,7 @@ int save_hotlist(WINDOW *win);
 int metaserver(char *url, int timeout, const char **errmsg);
 FILE *open_url(const char *url, int timeout, const char **errmsg);
 char *format_time(time_t t);
+int parse_time(char *str);
 
 #endif /* _NAP_CMDS_H */
 
