@@ -95,7 +95,12 @@
 #define F_SOP 0x273
 #define F_ANNOUNCE 0x274
 #define F_SBANLISTU 0x275
+
 /* 0x280-0x282 (640-642) direct browse */
+#define F_BROWSE2 0x280
+#define F_BROWSE2ACC 0x281
+#define F_BROWSE2ERR 0x282
+
 #define F_CLOAK 0x28c
 /* 0x2bc-0x2bf (700-703) change linkspeed/pw/e-mail/dataport */
 /* 0x2ec (748) login attempt [SERVER] */
