@@ -506,9 +506,6 @@ int dosend(WINDOW *win, sock_t *m)
     wp(win, ""RED"* Error: could not open local file \"%s\": %s"WHITE"\n", lfn, strerror(errno));
     drw(win);
     free(lfn);
-  } else if (r==-2) {
-    wp(win, ""RED"* Error: could not open local file \"%s\": ran out of filenames"WHITE"\n", fn);
-    drw(win);
   }
 
   if (r==-1 || r==-2) {
@@ -862,9 +859,6 @@ int gsize(WINDOW *win, sock_t *m)
     wp(win, ""RED"* Error: could not open local file \"%s\": %s"WHITE"\n", lfn, strerror(errno));
     drw(win);
     free(lfn);
-  } else if (r==-2) {
-    wp(win, ""RED"* Error: could not open local file \"%s\": ran out of filenames"WHITE"\n", task->fn);
-    drw(win);
   }
 
   if (r==-1 || r==-2) {
