@@ -60,7 +60,6 @@ extern WINDOW *wchan, *winput;
 extern char cbuf[];
 extern upload_t *up;
 extern download_t *down;
-extern int screen;
 
 chans_t *chanl = NULL, *curchan = NULL;
 hotlist_t *hlist = NULL;
@@ -369,11 +368,13 @@ int set_defaults_interactive(char *fn) {
   int conn;
   int r;
   struct stat st;
+  int userprompt = 0;
 
   ans = NULL;
 
   if (!getval("user")) {
     if (!info.daemon) {
+      userprompt = 1;
       wp(NULL, "User: ");
       ans = getline(stdin);
     }
@@ -394,8 +395,8 @@ int set_defaults_interactive(char *fn) {
   pass = getrealval("pass"); /* note: getval("pass") does not work - it always
 				returns "?" */
 
-  /* before prompting, check the variable pass.<user> */
-  if (!pass || !strcmp(pass,"?")) {
+  /* if password not defined, check the variable pass.<user> */
+  if (!pass || !strcmp(pass, "?")) {
     char tmp[10+strlen(user)];
     strcpy(tmp, "pass.");
     strcat(tmp, user);
@@ -406,22 +407,34 @@ int set_defaults_interactive(char *fn) {
   }
 
   if (!pass || !strcmp(pass,"?")) {
-    if (!info.daemon) {
-      wp(NULL, "Password for user %s: ", user);
+    if (userprompt) {
+      wp(NULL, "Password for user %s (optional): ", user);
       ans = getpass(""); /* note: getpass(3) does not allocate its
-			    result value, thus we should not free it. */
+                            result value, thus we should not free it. */
     }
-    if (!ans || !*ans) {
-      wp(NULL, "No password given\n");
-      return(-1);
-    } else {
+    if (ans && *ans) {
       chset("pass", ans);
     }
   }
-
   ans = NULL;
+  
+  pass = getrealval("pass");
+  if (!pass || !strcmp(pass, "?")) {
+    char pw[9];
+    struct timeval tv;
+    int i;
+    
+    gettimeofday(&tv, NULL);
+    srand(tv.tv_usec + 1000000*tv.tv_sec);
+    for (i=0; i<8; i++) {
+      pw[i] = rand() % 26 + 'a';
+    }
+    pw[8] = 0;
+    chset("pass", pw);
+    wp(NULL, "No password given - using random password\n");
+  }
 
-  /* before prompting, check the variable email.<user> */
+  /* if email not defined, check the variable email.<user> */
   if (!getval("email")) {
     char *email;
     char tmp[10+strlen(user)];
@@ -434,22 +447,20 @@ int set_defaults_interactive(char *fn) {
   }
 
   if (!getval("email")) {
-    if (!info.daemon) {
-      wp(NULL, "Email for user %s: ", user);
+    if (userprompt) {
+      wp(NULL, "Email for user %s (optional): ", user);
       ans = getline(stdin);
     }
-    if (!ans || !*ans) {
-      msprintf(&ans, "%s@localhost", user);
-      chset("email", ans);
-      wp(NULL, "No email given - trying %s\n", ans);
-    } else {
+    if (ans && *ans) {
       chset("email", ans);
       changes = 1;
     }
   }
-
-  free(ans);
-  ans = NULL;
+  
+  if (!getval("email")) {
+    chset("email", "anon@localhost");
+    wp(NULL, "No email given - using anon@localhost\n");
+  }
 
   if (!getval("upload")) {
     if (!info.daemon) {
@@ -964,8 +975,8 @@ int setup_configdir(void) {
 
   /* if the config directory already exists, return. In case there is
      a file .nap/nap.conf (as in older debian distributions), rename it. */
-  stat(configdir, &st);
-  if (S_ISDIR(st.st_mode)) {
+  r = stat(configdir, &st);
+  if ((r == 0) && S_ISDIR(st.st_mode)) {
     tmp1 = home_file(CONFIGDIR"/nap.conf");
     tmp2 = home_file(CONFIGFILE);
     move_file(tmp1, tmp2);
@@ -2142,8 +2153,16 @@ int login(int s, char *user, char *pass, int data, char *client, int conn, char
     free(rcv);
     return(-1);
   }
-  else if (strcasecmp(t1, email)) {
-    wp(wchan, "Email addresses did not match (%s and %s), proceeding anyway...\n", email, t1);
+
+  /* the following works for opennap and slavanap. The "email address"
+     they send is of the form anon@servername. Slavanap also sends an
+     additional integer. */
+  if (strncmp(t1, "anon@", 5)==0) {
+    char *p = strchr(t1, ' ');
+    if (p) {
+      *p = 0;
+    }
+    wp(wchan, "Server's name appears to be %s\n", t1+5);
     drw(wchan);
   }
 
