@@ -36,6 +36,7 @@
 extern info_t info;
 extern int srch;
 extern WINDOW *wchan;
+extern int reconnect;
 
 /* the global connection list */
 sock_t *socklist = NULL;
@@ -280,7 +281,7 @@ void sockfunc(WINDOW *win, WINDOW *up)
     /* if the --autorestart option is set, and there is no server, try to 
        reconnect to a server. */
 
-    if (info.autorestart) { 
+    if (info.autorestart == 1) { 
       for (cur=socklist;cur!=NULL;cur=cur->next) {
 	if (!strcasecmp(cur->socknm, "server"))
 	  break;
@@ -298,6 +299,12 @@ void sockfunc(WINDOW *win, WINDOW *up)
     if (quit_now)
       return;
 
+    /* we reconnect if this was requested by a SIGUSR1 signal */
+    if (reconnect) {
+      reconnect = 0;
+      dreconnect(-1, "reconnect", NULL, 0, win);
+    }
+
     /* determine current time */
     gettimeofday(&tv, NULL);
 
