@@ -775,17 +775,10 @@ I_NAP_FUNC(sqlimit)
 
   max = atoi(tok[3]);  /* maximal number of uploads the remote client allows */
 
-  if (max <= 0) { 
-    /* remote client allows no uploads - don't bother queueing */
-
-    wp(win, ""RED"* Unable to get \"%s\" from %s (remote client allows 0 uploads)"WHITE"\n", task->fn, task->nick);
-    drw(win);
-
-    task->state = FAILED;
-    task->d_time = time(0);
-
-    return(1);
-  }
+  /* if max<=0, the remote client allows 0 uploads, and we may as well
+     not bother queueing it. This is what we did in nap 1.4.8. Alas,
+     the stupid WinMX client *always* sends max=0, even when it is
+     not. Thus, we are essentially forced to ignore this value. */
 
   if (task->state == REQUESTED) {
     wp(win, "* Remotely queued \"%s\" from %s.\n", task->fn, task->nick);
@@ -1285,12 +1278,12 @@ I_NAP_FUNC(ssret)
   elt = (ssearch_t *)malloc(sizeof(ssearch_t));
   
   elt->song = strdup(quote(t));
-  elt->fn = strdup(tok[0]);
+  elt->rfn = strdup(tok[0]);
   elt->sz = atoi(tok[2]);
   elt->brate = atoi(tok[3]);
   elt->freq = atoi(tok[4]);
   elt->time = atoi(tok[5]);
-  elt->cmp = strdup(tok[6]);
+  elt->nick = strdup(tok[6]);
   elt->nip = htonl(swapl(strtoul(tok[7], (char **)NULL, 10)));
   elt->conn = atoi(tok[8]);
   if (elt->conn > 10 || elt->conn < 0)
@@ -1488,7 +1481,7 @@ void showresults(WINDOW *win, int level) {
       sec = cur->time%60;
       mb = ((float)cur->sz)/1048576.0;
       
-      wp(win, ""BOLD"%i. %s"WHITE" %ibps %ihz "BOLD"%i:%02i %.02fmb"WHITE" %s", i, (fl)?cur->fn:cur->song, cur->brate, cur->freq, min, sec, mb, cur->cmp);
+      wp(win, ""BOLD"%i. %s"WHITE" %ibps %ihz "BOLD"%i:%02i %.02fmb"WHITE" %s", i, (fl)?cur->rfn:cur->song, cur->brate, cur->freq, min, sec, mb, cur->nick);
 
       if (level>=1) {
 	wp(win, " "BOLD"%s"WHITE"", conns[cur->conn]);
@@ -1542,12 +1535,12 @@ I_NAP_FUNC(srbrowse)
   
   cur->ping = -2;
   cur->song = strdup(quote(t));
-  cur->fn = strdup(tok[1]);
+  cur->rfn = strdup(tok[1]);
   cur->sz = atoi(tok[3]);
   cur->brate = atoi(tok[4]);
   cur->freq = atoi(tok[5]);
   cur->time = atoi(tok[6]);
-  cur->cmp = strdup(tok[0]);
+  cur->nick = strdup(tok[0]);
   cur->conn = -1;
   cur->next = NULL;
   
