@@ -217,7 +217,7 @@ V_FUNC(vsearch)
     return(ret);
   }
   else if (!strcasecmp(tok[1], "user"))
-    return(strdup(cur->cmp));
+    return(strdup(cur->nick));
   else if (!strcasecmp(tok[1], "freq"))
   {
     msprintf(&ret, "%i", cur->freq);
@@ -236,7 +236,7 @@ V_FUNC(vsearch)
     return(ret);
   }
   else if (!strcasecmp(tok[1], "filename"))
-    return(strdup(cur->fn));
+    return(strdup(cur->rfn));
   else if (!strcasecmp(tok[1], "ping"))
   {
     msprintf(&ret, "%i", cur->ping);
