@@ -27,6 +27,8 @@
 #include "irc.h"
 #include "lists.h"
 #include "scheck.h"
+#include "sscr.h"
+#include "dlul_screen.h"
 
 #ifdef MEMWATCH
   #include "memwatch.h"
@@ -48,9 +50,9 @@ extern WINDOW *swin;
 /* the new model for managing input screens is as follows: */
 
 /* the number of the currently active screen. Currently three values
-   are possible: MAIN_SCREEN and RESULT_SCREEN. However, further
-   screens may be added in the future (such as: download screen,
-   upload screen, resume screen... */
+   are possible: MAIN_SCREEN, RESULT_SCREEN, and DLUL_SCREEN. However,
+   further screens may be added in the future (such as: resume screen,
+   configuration screen) */
 int screen;
 
 /* Each screen has its own curses windows, and its own global state
@@ -128,9 +130,10 @@ colortab_t colortab[] = {
   { NULL, -1, 0 }
 };
 
-/* switch to screen number n (which should be MAIN_SCREEN or
-  RESULT_SCREEN). Returns 0 if we already were on that screen (without
-  redrawing it), 1 if there was a real switch, and -1 on error. */  
+/* switch to screen number n (which should be MAIN_SCREEN,
+   RESULT_SCREEN, or DLUL_SCREEN). Returns 0 if we already were on
+   that screen (without redrawing it), 1 if there was a real switch,
+   and -1 on error. */
 int switchtoscreen(int n) {
 
   if (n==screen) {
@@ -141,6 +144,7 @@ int switchtoscreen(int n) {
   switch (n) {
   case MAIN_SCREEN:
   case RESULT_SCREEN:
+  case DLUL_SCREEN:
     break;
   default:
     return(-1);
@@ -154,6 +158,9 @@ int switchtoscreen(int n) {
   case RESULT_SCREEN:
     endsearchscr();
     break;
+  case DLUL_SCREEN:
+    enddlulscr();
+    break;
   default:
     return(-1);
     break;
@@ -169,6 +176,9 @@ int switchtoscreen(int n) {
   case RESULT_SCREEN:
     searchscr();
     break;
+  case DLUL_SCREEN:
+    dlulscr();
+    break;
   default: /* not reachable */
     return(-1);
     break;
@@ -183,6 +193,9 @@ int nextscreen(void) {
     switchtoscreen(RESULT_SCREEN);
     break;
   case RESULT_SCREEN:
+    switchtoscreen(DLUL_SCREEN);
+    break;
+  case DLUL_SCREEN:
   default:
     switchtoscreen(MAIN_SCREEN);
     break;
@@ -245,6 +258,9 @@ void resize()
   if (screen==RESULT_SCREEN) {
     plist();
   }
+  else if (screen == DLUL_SCREEN) {
+    dlul_refresh();
+  }
     
   return;
 }
@@ -268,6 +284,8 @@ void drw(WINDOW *win)
   
   if (screen==RESULT_SCREEN && win == swin)
     wrefresh(win);
+  else if (screen==DLUL_SCREEN && win == dlul_win)
+    wrefresh(win);
   else if (screen==MAIN_SCREEN)
     wrefresh(win);
 }
@@ -1112,18 +1130,23 @@ int input(WINDOW *win, sock_t *m)
     break;
     
   case 1:                               /* Ctrl-A */
+  case KEY_HOME:                        /* Home */
+  case KEY_FIND:                        /* Find - a kind of home key */
     curx = 0;
     indraw();
     ebuf = 0;
     break;
     
   case 5:                               /* Ctrl-E */
+  case KEY_END:                         /* End */
+  case KEY_SELECT:                      /* Select - a kind of end key */
     curx = strlen(cbuf);
     indraw();
     ebuf = 0;
     break;
 
   case 4:                               /* Ctrl-D */
+  case 330:                             /* Delete */
     if (cbuf[curx]) {
       memmove(cbuf+curx, cbuf+curx+1, strlen(cbuf+curx+1)+1);
     }
@@ -1220,7 +1243,7 @@ int input(WINDOW *win, sock_t *m)
 
   case KEY_NPAGE:                       /* PgDn */
   case 14:                              /* Ctrl-N */
-  case 22:                              /* Crtl-V */
+  case 22:                              /* Ctrl-V */
     dscroll(win, -(LINES-2)/2);
     indraw();
     ebuf = 0;
@@ -1242,16 +1265,21 @@ int input(WINDOW *win, sock_t *m)
     ebuf = 0;
     break;
 
+  case KEY_F(1):                        /* F1 */
+  case 128 + '1':                       /* M-1 */
+    return(1);
+    break;
+
   case KEY_F(2):                        /* F2 */
+  case 128 + '2':                       /* M-2 */
     switchtoscreen(RESULT_SCREEN);
     return(1);
     break;
-    
-  case KEY_END:                         /* END */
-  case KEY_SELECT:                      /* SELECT */
-    scur = NULL;
-    dscr(win);
-    drw(win);
+
+  case KEY_F(3):                        /* F3 */
+  case 128 + '3':                       /* M-3 */
+    switchtoscreen(DLUL_SCREEN);
+    return(1);
     break;
 
   case KEY_UP:                          /* UP */
@@ -1386,7 +1414,8 @@ void initwin(unsigned char f)
   init_pair(CPY, COLOR_YELLOW, bgcolor);
   init_pair(CPM, COLOR_MAGENTA, bgcolor);
   init_pair(CPC, COLOR_CYAN, bgcolor);
-  init_pair(CPBR, COLOR_WHITE, COLOR_RED);
+  init_pair(CPWR, COLOR_WHITE, COLOR_RED);
+  init_pair(CPWB, COLOR_WHITE, COLOR_BLUE);
   winput = newwin("input", 1, 0, LINES-1, 0);
 #else
   info.notop = 1;
