@@ -10,6 +10,7 @@
 
 #define MAIN_SCREEN 0
 #define RESULT_SCREEN 1
+#define DLUL_SCREEN 2
 
 struct colortab_s 
 {
@@ -47,6 +48,8 @@ struct scroll_s
 };
 typedef struct scroll_s scroll_t;
 
+extern int screen;
+
 #ifndef MCURSES
 void resize(void);
 #endif
@@ -64,8 +67,6 @@ void scrollbottom(void);
 void dscr(WINDOW *);
 void dscroll(WINDOW *, int);
 int doesc(WINDOW *, const char *);
-int cmdcnt(cmds_t *);
-cmds_t *cmdend(cmds_t *);
 int input(WINDOW *, sock_t *);
 void initwin(unsigned char);
 void indraw(void);
